<div align="center">

<p align="center">
  <img src="img/logo.svg" width="200" height="200" alt="logo" title="Tetris Stats"></a>
</p>

# Tetris Stats

✨ 一款基于 [NoneBot2](https://github.com/nonebot/nonebot2) 的用于查询 Tetris 相关游戏玩家数据的插件 ✨

</div>

<p align="center">
<a href="https://github.com/shoucandanghehe/nonebot-plugin-tetris-stats/blob/main/LICENSE">
  <img
    src="https://img.shields.io/github/license/shoucandanghehe/nonebot-plugin-tetris-stats"
    alt="License"
  />
</a>
<a href="https://www.python.org/">
  <img
    src="https://img.shields.io/badge/Python-3.10+-blue"
    alt="Python"
  />
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-tetris-stats">
  <img
    src="https://img.shields.io/pypi/v/nonebot-plugin-tetris-stats"
    alt="PyPi"
  />
</a>
<a href="https://github.com/charliermarsh/ruff">
  <img
    src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json"
    alt="Ruff"
  />
</a>
<a href="https://gitmoji.dev">
  <img
    src="https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67.svg?style=flat-square"
    alt="Gitmoji"
  />
</a>
<a href="https://wakatime.com/badge/user/138b2226-8e02-42be-b99d-35c05198836f/project/65f5bdf7-45ec-479a-8dd2-18c498c910ca">
  <img
    src="https://wakatime.com/badge/user/138b2226-8e02-42be-b99d-35c05198836f/project/65f5bdf7-45ec-479a-8dd2-18c498c910ca.svg"
    alt="wakatime"
    />
</a>
</p>

## ✨ 目前支持的游戏

- [TETR.IO](https://tetr.io/)
- [茶服](https://teatube.cn/tos/)
- [TOP](http://tetrisonline.pl/)

## 🚀 安装

- 使用 nb-cli

```bash
nb plugin install nonebot-plugin-tetris-stats
```

- 使用 poetry

```bash
poetry add nonebot-plugin-tetris-stats
```

- 使用 pip ~~不推荐~~

```bash
pip install nonebot-plugin-tetris-stats
```

## ♿️ 使用

- 参考 NoneBot2 文档 [加载插件](https://nonebot.dev/docs/tutorial/create-plugin#%E5%8A%A0%E8%BD%BD%E6%8F%92%E4%BB%B6)

## 🎉 鸣谢

- [NoneBot2](https://v2.nonebot.dev/)
- 所有为机器人生态做出贡献的人❤️

## 📝 开源

本项目使用 [AGPL-3.0](https://github.com/shoucandanghehe/nonebot-plugin-tetris-stats/blob/main/LICENSE) 许可证开源
